:orphan:

fsleyes_widgets.utils.colourbarbitmap module
============================================

.. automodule:: fsleyes_widgets.utils.colourbarbitmap
    :members:
    :undoc-members:
    :show-inheritance:
